##  Filtering in the Transformations Explorer
Filtering helps you quickly narrow down transformation items based on various criteria. This helps you focus on relevant data before editing, executing, or exporting.
### Filter by Transformation Type
The left-side panel allows you to filter transformation items by their type, such as introducing a new application, changing application technology, decommissioning an interface, and more.
To view all transformation items again, select All Transformations at the top
### Filter by Fact Sheet
When you filter by fact sheets, the transformations explorer shows all transformation items linked to those fact sheets. This includes items that are part of the transformation or indirectly affected.
For example, filtering by an application fact sheet under displays all transformations that introduce, update, or discontinue components related to that application.
To filter transformation items by fact sheet, follow these steps:
  1. Click By Affected Fact Sheet at the top to open the fact sheet filter modal.
  2. Add filters using + Add Filter or the filter panel on the left.
  3. You can then either:
    1. Click Use Fact Sheet Filter to view transformation items related to the selected filters.
    2. Or select specific fact sheets and click Use Selected Fact Sheets.


![Filtering by Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio0a8940f825f44cd88dd2aed5da7ef1ff_LowRes.gif)
Filtering by Fact Sheet
**Tip**
The By Project button opens the fact sheet filter prefiltered for initiative fact sheets, allowing you to quickly filter transformation items by initiatives and projects.
### Filter by Attribute
You can filter transformation items using attributes like initiative, status, completion date, creator, and more. For example, you can view only those transformations that are ready for execution by filtering for the status Ready to Execute.
To filter by attribute, do the following:
  1. Select a filter attribute.
  2. From the drop-down list, choose one or more filter criteria.


![Filtering By Transformation Item Status](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4c5fb3320e5a48ea831cde90c23344a6_LowRes.png)
Filtering By Transformation Item Status
**Tip**
  * You can apply multiple criteria across different attributes at the same time when filtering.
  * To view additional filter attributes beyond the default ones, click + Add Filter and select the attributes you need.


**Note**
To filter by milestones, first filter by projects. Only the milestones linked to the selected project will then appear as available filter options.
